@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: downloader-view.c,v 1.40 2003/11/30 14:08:16 chpe Exp $
+ *  $Id: downloader-view.c,v 1.41 2003/12/21 12:55:56 xan Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -498,10 +498,12 @@ download_dialog_pause_cb (GtkButton *button, DownloaderView *dv)
 	if (state == EPHY_DOWNLOAD_DOWNLOADING)
 	{
 		ephy_download_pause (download);
+		gtk_button_set_label (GTK_BUTTON (dv->priv->pause_button), _("Resume"));
 	}
 	else if (state == EPHY_DOWNLOAD_PAUSED)
 	{
 		ephy_download_resume (download);
+		gtk_button_set_label (GTK_BUTTON (dv->priv->pause_button), _("Pause"));
 	}
 }
 
