@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-favicon-cache.c,v 1.27 2003/11/22 11:32:31 marco Exp $
+ *  $Id: ephy-favicon-cache.c,v 1.28 2003/12/16 17:29:39 marco Exp $
  */
 
 #include <libgnomevfs/gnome-vfs-ops.h>
@@ -50,7 +50,6 @@ struct EphyFaviconCachePrivate
 	EphyNodeDb *db;
 	EphyNode *icons;
 	GHashTable *icons_hash;
-	GStaticRWLock *icons_hash_lock;
 	GHashTable *downloads_hash;
 };
 
@@ -142,13 +141,9 @@ icons_added_cb (EphyNode *node,
 		EphyNode *child,
 		EphyFaviconCache *eb)
 {
-	g_static_rw_lock_writer_lock (eb->priv->icons_hash_lock);
-
 	g_hash_table_insert (eb->priv->icons_hash,
 			     (char *) ephy_node_get_property_string (child, EPHY_NODE_FAVICON_PROP_URL),
 			     child);
-
-	g_static_rw_lock_writer_unlock (eb->priv->icons_hash_lock);
 }
 
 static void
@@ -156,12 +151,8 @@ icons_removed_cb (EphyNode *node,
 		  EphyNode *child,
 		  EphyFaviconCache *eb)
 {
-	g_static_rw_lock_writer_lock (eb->priv->icons_hash_lock);
-
 	g_hash_table_remove (eb->priv->icons_hash,
 			     ephy_node_get_property_string (child, EPHY_NODE_FAVICON_PROP_URL));
-
-	g_static_rw_lock_writer_unlock (eb->priv->icons_hash_lock);
 }
 
 static void
@@ -177,7 +168,6 @@ remove_obsolete_icons (EphyFaviconCache *eb)
 	g_date_set_time (&current_date, time (NULL));
 
 	children = ephy_node_get_children (eb->priv->icons);
-	ephy_node_thaw (eb->priv->icons);
 	for (i = 0; i < children->len; i++)
 	{
 		EphyNode *kid;
@@ -227,8 +217,6 @@ ephy_favicon_cache_init (EphyFaviconCache *cache)
 
 	cache->priv->icons_hash = g_hash_table_new (g_str_hash,
 						    g_str_equal);
-	cache->priv->icons_hash_lock = g_new0 (GStaticRWLock, 1);
-	g_static_rw_lock_init (cache->priv->icons_hash_lock);
 	cache->priv->downloads_hash = g_hash_table_new_full (g_str_hash,
 							     g_str_equal,
 							     g_free,
@@ -263,9 +251,7 @@ kill_download (gpointer key,
 	ephy_embed_persist_cancel (persist);
 	g_object_unref (persist);
 
-	g_static_rw_lock_reader_lock (cache->priv->icons_hash_lock);
 	icon = g_hash_table_lookup (cache->priv->icons_hash, (char *)key);
-	g_static_rw_lock_reader_unlock (cache->priv->icons_hash_lock);
 
 	ephy_node_unref (icon);
 
@@ -300,8 +286,6 @@ ephy_favicon_cache_finalize (GObject *object)
 	g_free (cache->priv->xml_file);
 	g_free (cache->priv->directory);
 	g_hash_table_destroy (cache->priv->icons_hash);
-	g_static_rw_lock_free (cache->priv->icons_hash_lock);
-	g_free (cache->priv->icons_hash_lock);
 	g_hash_table_destroy (cache->priv->downloads_hash);
 
 	g_object_unref (cache->priv->db);
@@ -390,9 +374,7 @@ ephy_favicon_cache_get (EphyFaviconCache *cache,
 
 	now = time (NULL);
 
-	g_static_rw_lock_reader_lock (cache->priv->icons_hash_lock);
 	icon = g_hash_table_lookup (cache->priv->icons_hash, url);
-	g_static_rw_lock_reader_unlock (cache->priv->icons_hash_lock);
 
 	if (!icon)
 	{
