@@ -118,10 +118,11 @@ protected:
 	PRInt32                 mCurrentProgress;
 
 	bool                    mGotFirstStateChange, mIsNetworkTransfer;
-	bool                    mUserCanceled;
 	nsresult                mStatus;
-   
+
+	nsCOMPtr<nsIObserver>		mObserver;   
 	nsCOMPtr<nsIWebBrowserPersist>  mWebPersist;
+	nsCOMPtr<nsIRequest>		mRequest;
 	EphyDownload                   *mEphyDownload;
 	DownloaderView                 *mDownloaderView;
 	MozillaEmbedPersist            *mEmbedPersist;
