@@ -16,12 +16,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: print-dialog.c,v 1.15 2003/12/07 10:23:22 chpe Exp $
+ *  $Id: print-dialog.c,v 1.18 2003/12/19 18:13:53 chpe Exp $
  */
 
 #include "print-dialog.h"
 #include "ephy-embed-dialog.h"
 #include "ephy-file-chooser.h"
+#include "ephy-stock-icons.h"
 #include "eel-gconf-extensions.h"
 #include "ephy-debug.h"
 
@@ -58,6 +59,7 @@ enum
 	PRINTON_PROP,
 	PRINTER_PROP,
 	FILE_PROP,
+	BROWSE_PROP,
 	ALL_PAGES_PROP,
 	SELECTION_PROP,
 	TO_PROP,
@@ -71,6 +73,7 @@ EphyDialogProperty print_props [] =
 	{ "printer_radiobutton",		CONF_PRINT_PRINTON,	  PT_AUTOAPPLY, 0 },
 	{ "printer_entry",			CONF_PRINT_PRINTER,	  PT_AUTOAPPLY, 0 },
 	{ "file_entry",				CONF_PRINT_FILE,	  PT_AUTOAPPLY, 0 },
+	{ "browse_button",			NULL,			  PT_NORMAL,	0 },
 	{ "all_pages_radiobutton",		CONF_PRINT_ALL_PAGES,	  PT_AUTOAPPLY, 0 },
 	{ "selection_radiobutton",		NULL,			  PT_NORMAL,    0 },
 	{ "to_spinbutton",			CONF_PRINT_FROM_PAGE,	  PT_AUTOAPPLY, G_TYPE_INT },
@@ -275,8 +278,6 @@ ephy_print_dialog_browse_button_cb (GtkWidget *widget,
 				    GTK_FILE_CHOOSER_ACTION_SAVE,
 				    CONF_PRINT_DIR);
 
-	gtk_window_set_destroy_with_parent (GTK_WINDOW (fc), TRUE);
-
 	g_signal_connect (GTK_DIALOG (fc), "response",
 			  G_CALLBACK (print_filechooser_response_cb),
 			  dialog);
@@ -297,7 +298,7 @@ ephy_print_dialog_new (GtkWidget *parent,
 		       gboolean only_collect_info)
 {
 	EphyDialog *dialog;
-	GtkWidget *window;
+	GtkWidget *window, *button;
 	GdkPixbuf *icon;
 
 	dialog =  EPHY_DIALOG (g_object_new (EPHY_TYPE_EMBED_DIALOG,
@@ -320,6 +321,9 @@ ephy_print_dialog_new (GtkWidget *parent,
 	gtk_window_set_icon (GTK_WINDOW (window), icon);
 	g_object_unref (icon);
 
+	button = ephy_dialog_get_control (dialog, print_props[BROWSE_PROP].id);
+	gtk_widget_set_sensitive (button, eel_gconf_key_is_writable (CONF_PRINT_FILE));
+
 	g_object_set_data (G_OBJECT (dialog), "only-collect-info",
 			   GINT_TO_POINTER (only_collect_info));
 
@@ -343,7 +347,7 @@ ephy_print_setup_dialog_new (void)
 
 	window = ephy_dialog_get_control (dialog, setup_props[SETUP_WINDOW_PROP].id);
 	icon = gtk_widget_render_icon (window,
-				       GTK_STOCK_PROPERTIES,
+				       STOCK_PRINT_SETUP,
 				       GTK_ICON_SIZE_MENU,
 				       "print_setup_dialog");
 	gtk_window_set_icon (GTK_WINDOW (window), icon);
