@@ -18,11 +18,21 @@
 
 #include "egg-editable-toolbar.h"
 #include "egg-toolbars-model.h"
-#include "eggtoolbar.h"
-#include "eggtoolitem.h"
-#include "eggseparatortoolitem.h"
-#include "eggintl.h"
 
+#include <gtk/gtkvseparator.h>
+#include <gtk/gtkiconfactory.h>
+#include <gtk/gtkwindow.h>
+#include <gtk/gtkmain.h>
+#include <gtk/gtkdnd.h>
+#include <gtk/gtkhbox.h>
+#include <gtk/gtkimage.h>
+#include <gtk/gtkimagemenuitem.h>
+#include <gtk/gtkmenu.h>
+#include <gtk/gtkstock.h>
+#include <gtk/gtktoolbar.h>
+#include <gtk/gtktoolitem.h>
+#include <gtk/gtkseparatortoolitem.h>
+#include <glib/gi18n.h>
 #include <string.h>
 
 static void egg_editable_toolbar_class_init	(EggEditableToolbarClass *klass);
@@ -50,20 +60,27 @@ enum
 
 enum
 {
-	ACTION_REQUEST,
-	LAST_SIGNAL
+  ACTION_REQUEST,
+  LAST_SIGNAL
 };
 
 static guint egg_editable_toolbar_signals[LAST_SIGNAL] = { 0 };
 
 static GObjectClass *parent_class = NULL;
 
+#define EGG_EDITABLE_TOOLBAR_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EGG_TYPE_EDITABLE_TOOLBAR, EggEditableToolbarPrivate))
+
 struct EggEditableToolbarPrivate
 {
-  EggMenuMerge *merge;
+  GtkUIManager *merge;
   EggToolbarsModel *model;
   gboolean edit_mode;
   GtkWidget *selected_toolbar;
+  GtkWidget *fixed_toolbar;
+
+  gboolean pending;
+  GtkToolbar *target_toolbar;
+  GtkWidget *dragged_item;
 };
 
 GType
@@ -100,7 +117,7 @@ get_toolbar_position (EggEditableToolbar *etoolbar, GtkWidget *toolbar)
   int result;
 
   l = gtk_container_get_children (GTK_CONTAINER (etoolbar));
-  result = g_list_index (l, toolbar);
+  result = g_list_index (l, toolbar->parent);
   g_list_free (l);
 
   return result;
@@ -120,8 +137,8 @@ get_n_toolbars (EggEditableToolbar *etoolbar)
 }
 
 static GtkWidget *
-get_toolbar_nth (EggEditableToolbar *etoolbar,
-		 int                 position)
+get_dock_nth (EggEditableToolbar *etoolbar,
+	      int                 position)
 {
   GList *l;
   GtkWidget *result;
@@ -133,21 +150,40 @@ get_toolbar_nth (EggEditableToolbar *etoolbar,
   return result;
 }
 
-static EggAction *
+static GtkWidget *
+get_toolbar_nth (EggEditableToolbar *etoolbar,
+		 int                 position)
+{
+  GList *l;
+  GtkWidget *dock;
+  GtkWidget *result;
+
+  dock = get_dock_nth (etoolbar, position);
+
+  l = gtk_container_get_children (GTK_CONTAINER (dock));
+  result = GTK_WIDGET (l->data);
+  g_list_free (l);
+
+  return result;
+}
+
+static GtkAction *
 find_action (EggEditableToolbar *t,
 	     const char         *name)
 {
-  GList *l = t->priv->merge->action_groups;
-  EggAction *action = NULL;
+  GList *l;
+  GtkAction *action = NULL;
 
-  g_return_val_if_fail (IS_EGG_EDITABLE_TOOLBAR (t), NULL);
+  l = gtk_ui_manager_get_action_groups (t->priv->merge);
+
+  g_return_val_if_fail (EGG_IS_EDITABLE_TOOLBAR (t), NULL);
   g_return_val_if_fail (name != NULL, NULL);
 
   for (; l != NULL; l = l->next)
     {
-      EggAction *tmp;
+      GtkAction *tmp;
 
-      tmp = egg_action_group_get_action (EGG_ACTION_GROUP (l->data), name);
+      tmp = gtk_action_group_get_action (GTK_ACTION_GROUP (l->data), name);
       if (tmp)
 	action = tmp;
     }
@@ -155,45 +191,6 @@ find_action (EggEditableToolbar *t,
   return action;
 }
 
-static void
-drag_data_received_cb (GtkWidget          *widget,
-		       GdkDragContext     *context,
-		       gint                x,
-		       gint                y,
-		       GtkSelectionData   *selection_data,
-		       guint               info,
-		       guint               time_,
-		       EggEditableToolbar *etoolbar)
-{
-  int pos, toolbar_pos;
-
-  g_return_if_fail (IS_EGG_EDITABLE_TOOLBAR (etoolbar));
-
-  pos = egg_toolbar_get_drop_index (EGG_TOOLBAR (widget), x, y);
-  toolbar_pos = get_toolbar_position (etoolbar, widget);
-
-  if (strcmp (selection_data->data, "separator") == 0)
-    {
-      egg_toolbars_model_add_separator (etoolbar->priv->model,
-					toolbar_pos, pos);
-    }
-  else
-    {
-      GdkAtom target;
-      char *type;
-      char *id;
-
-      target = gtk_drag_dest_find_target (widget, context, NULL);
-      type = egg_toolbars_model_get_item_type (etoolbar->priv->model, target);
-      id = egg_toolbars_model_get_item_id (etoolbar->priv->model, type,
-					   selection_data->data);
-      egg_toolbars_model_add_item (etoolbar->priv->model,
-			           toolbar_pos, pos, id, type);
-      g_free (type);
-      g_free (id);
-    }
-}
-
 static void
 drag_data_delete_cb (GtkWidget          *widget,
 		     GdkDragContext     *context,
@@ -201,16 +198,32 @@ drag_data_delete_cb (GtkWidget          *widget,
 {
   int pos, toolbar_pos;
 
-  g_return_if_fail (IS_EGG_EDITABLE_TOOLBAR (etoolbar));
+  g_return_if_fail (EGG_IS_EDITABLE_TOOLBAR (etoolbar));
 
-  pos = egg_toolbar_get_item_index (EGG_TOOLBAR (widget->parent),
-				    EGG_TOOL_ITEM (widget));
+  pos = gtk_toolbar_get_item_index (GTK_TOOLBAR (widget->parent),
+				    GTK_TOOL_ITEM (widget));
   toolbar_pos = get_toolbar_position (etoolbar, widget->parent);
 
   egg_toolbars_model_remove_item (etoolbar->priv->model,
 			          toolbar_pos, pos);
 }
 
+static void
+drag_begin_cb (GtkWidget          *widget,
+	       GdkDragContext     *context,
+	       EggEditableToolbar *etoolbar)
+{
+	gtk_widget_hide (widget);
+}
+
+static void
+drag_end_cb (GtkWidget          *widget,
+	     GdkDragContext     *context,
+	     EggEditableToolbar *etoolbar)
+{
+	gtk_widget_show (widget);
+}
+
 static void
 drag_data_get_cb (GtkWidget          *widget,
 		  GdkDragContext     *context,
@@ -219,16 +232,16 @@ drag_data_get_cb (GtkWidget          *widget,
 		  guint32             time,
 		  EggEditableToolbar *etoolbar)
 {
-  EggAction *action;
+  GtkAction *action;
   const char *target;
 
-  g_return_if_fail (IS_EGG_EDITABLE_TOOLBAR (etoolbar));
+  g_return_if_fail (EGG_IS_EDITABLE_TOOLBAR (etoolbar));
 
-  action = EGG_ACTION (g_object_get_data (G_OBJECT (widget), "egg-action"));
+  action = GTK_ACTION (g_object_get_data (G_OBJECT (widget), "gtk-action"));
 
   if (action)
     {
-      target = action->name;
+      target = gtk_action_get_name (action);
     }
   else
     {
@@ -239,6 +252,224 @@ drag_data_get_cb (GtkWidget          *widget,
 			  selection_data->target, 8, target, strlen (target));
 }
 
+static void
+set_drag_cursor (GtkWidget *widget)
+{
+  if (widget->window)
+    {
+      GdkCursor *cursor;
+      GdkPixbuf *pixbuf;
+
+      pixbuf = gdk_pixbuf_new_from_file (CURSOR_DIR "/art/hand-open.png", NULL);
+      cursor = gdk_cursor_new_from_pixbuf (gdk_display_get_default (),
+					   pixbuf, 12, 12);
+      gdk_window_set_cursor (widget->window, cursor);
+      gdk_cursor_unref (cursor);
+      g_object_unref (pixbuf);
+    }
+}
+
+static void
+unset_drag_cursor (GtkWidget *widget)
+{
+  if (widget->window)
+    {
+      gdk_window_set_cursor (widget->window, NULL);
+    }
+}
+
+static void
+set_item_drag_source (GtkWidget *item,
+		      GtkAction *action,
+		      gboolean   is_separator)
+{
+  gtk_drag_source_set (item, GDK_BUTTON1_MASK,
+		       source_drag_types, n_source_drag_types,
+		       GDK_ACTION_MOVE);
+
+  if (is_separator)
+    {
+      GtkWidget *icon;
+      GdkPixbuf *pixbuf;
+
+      icon = _egg_editable_toolbar_new_separator_image ();
+      pixbuf = gtk_image_get_pixbuf (GTK_IMAGE (icon));
+      gtk_drag_source_set_icon_pixbuf (item, pixbuf);
+    }
+  else
+    {
+      const char *stock_id;
+      GValue value = { 0, };
+      GdkPixbuf *pixbuf;
+
+      g_value_init (&value, G_TYPE_STRING);
+      g_object_get_property (G_OBJECT (action), "stock_id", &value);
+      stock_id = g_value_get_string (&value);
+
+      if (stock_id != NULL)
+        {
+          pixbuf = gtk_widget_render_icon (item, stock_id,
+				           GTK_ICON_SIZE_LARGE_TOOLBAR, NULL);
+        }
+      else
+        {
+          pixbuf = gtk_widget_render_icon (item, GTK_STOCK_DND,
+					   GTK_ICON_SIZE_LARGE_TOOLBAR, NULL);
+        }
+
+      gtk_drag_source_set_icon_pixbuf (item, pixbuf);
+      g_object_unref (pixbuf);
+
+      g_value_unset (&value);
+    }
+}
+
+static GtkWidget *
+create_item_from_action (EggEditableToolbar *t,
+			 const char *action_name,
+			 gboolean is_separator,
+			 GtkAction **ret_action)
+{
+  GtkWidget *item;
+  GtkAction *action;
+
+  if (is_separator)
+    {
+      item = GTK_WIDGET (gtk_separator_tool_item_new ());
+      action = NULL;
+    }
+  else
+    {
+      g_signal_emit (G_OBJECT (t), egg_editable_toolbar_signals[ACTION_REQUEST],
+		     0, action_name);
+
+      action = find_action (t, action_name);
+      if (action)
+        {
+          item = gtk_action_create_tool_item (action);
+        }
+      else
+        {
+          return NULL;
+        }  
+    }
+
+  gtk_widget_show (item);
+
+  g_signal_connect (item, "drag_begin",
+		    G_CALLBACK (drag_begin_cb), t);
+  g_signal_connect (item, "drag_end",
+		    G_CALLBACK (drag_end_cb), t);
+  g_signal_connect (item, "drag_data_get",
+		    G_CALLBACK (drag_data_get_cb), t);
+  g_signal_connect (item, "drag_data_delete",
+		    G_CALLBACK (drag_data_delete_cb), t);
+
+  if (t->priv->edit_mode)
+    {
+      set_drag_cursor (item);
+      gtk_widget_set_sensitive (item, TRUE);
+      set_item_drag_source (item, action, is_separator);
+      gtk_tool_item_set_use_drag_window (GTK_TOOL_ITEM (item), TRUE);
+    }
+
+  if (ret_action)
+    {
+      *ret_action = action;
+    }
+
+  return item;
+}
+
+static GtkWidget *
+create_item (EggEditableToolbar *t,
+	     EggToolbarsModel   *model,
+	     int                 toolbar_position,
+	     int                 position,
+             GtkAction         **ret_action)
+{
+  const char *action_name;
+  gboolean is_separator;
+
+  action_name = egg_toolbars_model_item_nth
+		(model, toolbar_position, position, &is_separator);
+  return create_item_from_action (t, action_name, is_separator, ret_action);
+}
+
+static gboolean
+data_is_separator (const char *data)
+{
+  return strcmp (data, "separator") == 0;
+}
+
+static void
+drag_data_received_cb (GtkWidget          *widget,
+		       GdkDragContext     *context,
+		       gint                x,
+		       gint                y,
+		       GtkSelectionData   *selection_data,
+		       guint               info,
+		       guint               time,
+		       EggEditableToolbar *etoolbar)
+{
+  char *type;
+  char *id;
+
+  GdkAtom target;
+	  
+  target = gtk_drag_dest_find_target (widget, context, NULL);
+  type = egg_toolbars_model_get_item_type (etoolbar->priv->model, target);
+  id = egg_toolbars_model_get_item_id (etoolbar->priv->model, type,
+				       selection_data->data);
+
+  /* This function can be called for two reasons
+   *
+   *  (1) drag_motion() needs an item to pass to
+   *      gtk_toolbar_set_drop_highlight_item(). We can
+   *      recognize this case by etoolbar->priv->pending being TRUE
+   *      We should just create an item and return.
+   *
+   *  (2) The drag has finished, and drag_drop() wants us to
+   *      actually add a new item to the toolbar.
+   */
+
+  if (etoolbar->priv->pending)
+    {
+      etoolbar->priv->pending = FALSE;
+      etoolbar->priv->dragged_item =
+        create_item_from_action (etoolbar, id, data_is_separator (id), NULL);
+    }
+  else
+    {
+      int pos, toolbar_pos;
+
+      pos = gtk_toolbar_get_drop_index (GTK_TOOLBAR (widget), x, y);
+      toolbar_pos = get_toolbar_position (etoolbar, widget);
+
+      if (data_is_separator (selection_data->data))
+	{
+	  egg_toolbars_model_add_separator (etoolbar->priv->model,
+					    toolbar_pos, pos);
+	}
+      else
+	{
+	  type = egg_toolbars_model_get_item_type (etoolbar->priv->model,
+						   target);
+	  id = egg_toolbars_model_get_item_id (etoolbar->priv->model, type,
+					       selection_data->data);
+
+	  egg_toolbars_model_add_item (etoolbar->priv->model,
+				       toolbar_pos, pos, id, type);
+	}
+      
+      gtk_drag_finish (context, TRUE, context->action == GDK_ACTION_MOVE,
+		       time);
+    }
+
+  g_free (type);
+  g_free (id);
+}
+
 static void
 remove_toolbar_cb (GtkWidget          *menuitem,
 		   EggEditableToolbar *etoolbar)
@@ -251,6 +482,9 @@ remove_toolbar_cb (GtkWidget          *menuitem,
 
 static void
 popup_toolbar_context_menu_cb (GtkWidget          *toolbar,
+			       gint		   x,
+			       gint		   y,
+			       gint                button_number,
 			       EggEditableToolbar *t)
 {
   GtkWidget *menu;
@@ -288,92 +522,158 @@ popup_toolbar_context_menu_cb (GtkWidget          *toolbar,
     }
 }
 
-static GtkWidget *
-create_toolbar (EggEditableToolbar *t)
+static void
+free_dragged_item (EggEditableToolbar *etoolbar)
 {
-  GtkWidget *toolbar;
+  if (etoolbar->priv->dragged_item)
+    {
+      gtk_widget_destroy (etoolbar->priv->dragged_item);
+      g_object_unref (etoolbar->priv->dragged_item);
+      etoolbar->priv->dragged_item = NULL;
+    }
+}
 
-  toolbar = egg_toolbar_new ();
-  egg_toolbar_set_show_arrow (EGG_TOOLBAR (toolbar), TRUE);
+static gboolean
+toolbar_drag_drop_cb (GtkWidget          *widget,
+		      GdkDragContext     *context,
+		      gint                x,
+		      gint                y,
+		      guint               time,
+		      EggEditableToolbar *etoolbar)
+{
+  GdkAtom target;
+
+  target = gtk_drag_dest_find_target (widget, context, NULL);
+  if (target != GDK_NONE)
+    {
+      gtk_drag_get_data (widget, context,
+                         target,
+                         time);
+      return TRUE;
+    }
+  
+  free_dragged_item (etoolbar);
+  
+  return FALSE;
+}
+
+static gboolean
+toolbar_drag_motion_cb (GtkWidget          *widget,
+		        GdkDragContext     *context,
+		        gint                x,
+		        gint                y,
+		        guint               time,
+		        EggEditableToolbar *etoolbar)
+{
+  GdkAtom target;
+  int index;
+  GtkToolbar *toolbar = GTK_TOOLBAR (widget);
+  GtkToolItem *item;
+
+  target = gtk_drag_dest_find_target (widget, context, NULL);
+  if (target == GDK_NONE)
+    {
+      gdk_drag_status (context, 0, time);
+      return FALSE;
+    }
+
+  if (etoolbar->priv->target_toolbar != toolbar)
+    {
+      if (etoolbar->priv->target_toolbar)
+	gtk_toolbar_set_drop_highlight_item
+		(etoolbar->priv->target_toolbar, NULL, 0);
+      
+      free_dragged_item (etoolbar);
+      etoolbar->priv->pending = TRUE;
+
+      etoolbar->priv->target_toolbar = toolbar;
+
+      /* The handler will make sure the item is created */
+      gtk_drag_get_data (widget, context, target, time);
+
+      g_assert (etoolbar->priv->dragged_item);
+      g_assert (!etoolbar->priv->pending);
+
+      g_object_ref (etoolbar->priv->dragged_item);
+      gtk_object_sink (GTK_OBJECT (etoolbar->priv->dragged_item));
+    }
+
+  item = GTK_TOOL_ITEM (etoolbar->priv->dragged_item);
+
+  index = gtk_toolbar_get_drop_index (toolbar, x, y);
+  gtk_toolbar_set_drop_highlight_item (toolbar, item, index);
+
+  gdk_drag_status (context, context->suggested_action, time);
+
+  return TRUE;
+}
+
+static void
+toolbar_drag_leave_cb (GtkToolbar         *toolbar,
+		       GdkDragContext     *context,
+		       guint               time,
+		       EggEditableToolbar *etoolbar)
+{
+  /* This is a workaround for bug 125557. Sometimes
+   * we seemingly enter another toolbar *before* leaving
+   * the current one.
+   *
+   * In that case etoolbar->priv->target_toolbar will
+   * have been set to something else and the highlighting
+   * will already have been turned off
+   */
+  
+  if (etoolbar->priv->target_toolbar == toolbar)
+    {
+      gtk_toolbar_set_drop_highlight_item (toolbar, NULL, 0);
+
+      etoolbar->priv->target_toolbar = NULL;
+      free_dragged_item (etoolbar);
+    }
+}
+
+static GtkWidget *
+create_dock (EggEditableToolbar *t)
+{
+  GtkWidget *toolbar, *hbox;
+
+  hbox = gtk_hbox_new (0, FALSE);
+  gtk_widget_show (hbox);
+
+  toolbar = gtk_toolbar_new ();
+  gtk_toolbar_set_show_arrow (GTK_TOOLBAR (toolbar), TRUE);
   gtk_widget_show (toolbar);
-  gtk_drag_dest_set (toolbar, GTK_DEST_DEFAULT_DROP,
+  gtk_box_pack_start (GTK_BOX (hbox), toolbar, TRUE, TRUE, 0);
+
+  gtk_drag_dest_set (toolbar, 0,
 		     dest_drag_types, n_dest_drag_types,
 		     GDK_ACTION_MOVE | GDK_ACTION_COPY);
+ 
+  g_signal_connect (toolbar, "drag_drop",
+		    G_CALLBACK (toolbar_drag_drop_cb), t); 
+  g_signal_connect (toolbar, "drag_motion",
+		    G_CALLBACK (toolbar_drag_motion_cb), t);
+  g_signal_connect (toolbar, "drag_leave",
+		    G_CALLBACK (toolbar_drag_leave_cb), t);
+
   g_signal_connect (toolbar, "drag_data_received",
 		    G_CALLBACK (drag_data_received_cb), t);
   g_signal_connect (toolbar, "popup_context_menu",
 		    G_CALLBACK (popup_toolbar_context_menu_cb), t);
 
-  return toolbar;
+  return hbox;
 }
 
 static void
-set_item_drag_source (GtkWidget *item,
-		      EggAction *action,
-		      gboolean   is_separator)
+set_fixed_style (EggEditableToolbar *t, GtkToolbarStyle style)
 {
-  gtk_drag_source_set (item, GDK_BUTTON1_MASK,
-		       source_drag_types, n_source_drag_types,
-		       GDK_ACTION_MOVE);
-
-  if (is_separator)
-    {
-      GtkWidget *icon;
-      GdkPixbuf *pixbuf;
-
-      icon = _egg_editable_toolbar_new_separator_image ();
-      pixbuf = gtk_image_get_pixbuf (GTK_IMAGE (icon));
-      gtk_drag_source_set_icon_pixbuf (item, pixbuf);
-    }
-  else
-    {
-      gtk_drag_source_set_icon_stock
-	(item, action->stock_id ? action->stock_id : GTK_STOCK_DND);
-    }
+  gtk_toolbar_set_style (GTK_TOOLBAR (t->priv->fixed_toolbar), style);
 }
 
-static GtkWidget *
-create_item (EggEditableToolbar *t,
-	     EggToolbarsModel   *model,
-	     int                 toolbar_position,
-	     int                 position)
+static void
+unset_fixed_style (EggEditableToolbar *t)
 {
-  GtkWidget *item;
-  const char *action_name;
-  gboolean is_separator;
-  EggAction *action;
-
-  action_name = egg_toolbars_model_item_nth
-		(model, toolbar_position, position,
-		 &is_separator);
-
-  if (is_separator)
-    {
-      item = GTK_WIDGET (egg_separator_tool_item_new ());
-      action = NULL;
-    }
-  else
-    {
-      g_signal_emit (G_OBJECT (t), egg_editable_toolbar_signals[ACTION_REQUEST],
-		     0, action_name);
-      action = find_action (t, action_name);
-      item = egg_action_create_tool_item (action);
-      gtk_widget_set_sensitive (item, TRUE);
-    }
-
-  gtk_widget_show (item);
-  g_signal_connect (item, "drag_data_get",
-		    G_CALLBACK (drag_data_get_cb), t);
-  g_signal_connect (item, "drag_data_delete",
-		    G_CALLBACK (drag_data_delete_cb), t);
-
-  if (t->priv->edit_mode)
-    {
-      set_item_drag_source (item, action, is_separator);
-      egg_tool_item_set_use_drag_window (EGG_TOOL_ITEM (item), TRUE);
-    }
-
-  return item;
+  gtk_toolbar_unset_style (GTK_TOOLBAR (t->priv->fixed_toolbar));
 }
 
 static void
@@ -389,26 +689,70 @@ toolbar_changed_cb (EggToolbarsModel   *model,
 
   if (flags & EGG_TB_MODEL_ICONS_ONLY)
   {
-    egg_toolbar_set_style (EGG_TOOLBAR (toolbar), GTK_TOOLBAR_ICONS);
+    gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), GTK_TOOLBAR_ICONS);
+    if (position == 0)
+      {
+        set_fixed_style (t, GTK_TOOLBAR_ICONS);
+      }
   }
   else
   {
-    egg_toolbar_unset_style (EGG_TOOLBAR (toolbar));
+    gtk_toolbar_unset_style (GTK_TOOLBAR (toolbar));
+    if (position == 0)
+      {
+        unset_fixed_style (t);
+      }
   }
 }
 
+static void
+unparent_fixed (EggEditableToolbar *t)
+{
+  GtkWidget *toolbar, *dock;
+
+  toolbar = t->priv->fixed_toolbar;
+  dock = get_dock_nth (t, 0);
+
+  if (dock && toolbar->parent != NULL)
+    {
+      gtk_container_remove (GTK_CONTAINER (dock), toolbar);
+    }
+}
+
+static void
+update_fixed (EggEditableToolbar *t)
+{
+  GtkWidget *toolbar, *dock;
+
+  toolbar = t->priv->fixed_toolbar;
+  dock = get_dock_nth (t, 0);
+
+  if (dock && toolbar && toolbar->parent == NULL)
+    {
+      gtk_box_pack_end (GTK_BOX (dock), toolbar, FALSE, TRUE, 0);
+
+      gtk_widget_show_all (toolbar);
+    }
+}
+
 static void
 toolbar_added_cb (EggToolbarsModel   *model,
 	          int                 position,
 	          EggEditableToolbar *t)
 {
-  GtkWidget *toolbar;
+  GtkWidget *dock;
 
-  toolbar = create_toolbar (t);
-  gtk_widget_set_size_request (toolbar, -1, MIN_TOOLBAR_HEIGHT);
-  gtk_box_pack_start (GTK_BOX (t), toolbar, FALSE, FALSE, 0);
+  dock = create_dock (t);
 
-  gtk_box_reorder_child (GTK_BOX (t), toolbar, position);
+  gtk_widget_set_size_request (dock, -1, MIN_TOOLBAR_HEIGHT);
+
+  gtk_box_pack_start (GTK_BOX (t), dock, TRUE, TRUE, 0);
+
+  gtk_box_reorder_child (GTK_BOX (t), dock, position);
+
+  gtk_widget_show_all (dock);
+  
+  update_fixed (t);
 }
 
 static void
@@ -418,8 +762,10 @@ toolbar_removed_cb (EggToolbarsModel   *model,
 {
   GtkWidget *toolbar;
 
-  toolbar = get_toolbar_nth (t, position);
+  toolbar = get_dock_nth (t, position);
   gtk_widget_destroy (toolbar);
+
+  update_fixed (t);
 }
 
 static void
@@ -430,12 +776,19 @@ item_added_cb (EggToolbarsModel   *model,
 {
   GtkWidget *toolbar;
   GtkWidget *item;
+  GtkAction *action;
 
   toolbar = get_toolbar_nth (t, toolbar_position);
   gtk_widget_set_size_request (toolbar, -1, -1);
-  item = create_item (t, model, toolbar_position, position);
-  egg_toolbar_insert (EGG_TOOLBAR (toolbar),
-		      EGG_TOOL_ITEM (item), position);
+  item = create_item (t, model, toolbar_position, position, &action);
+  gtk_toolbar_insert (GTK_TOOLBAR (toolbar),
+		      GTK_TOOL_ITEM (item), position);
+
+  /* FIXME Hack to make tooltip work from gtk */
+  if (action)
+    {
+      g_object_notify (G_OBJECT (action), "tooltip");
+    }
 }
 
 static void
@@ -448,36 +801,34 @@ item_removed_cb (EggToolbarsModel   *model,
   GtkWidget *item;
 
   toolbar = get_toolbar_nth (t, toolbar_position);
-  item = GTK_WIDGET (egg_toolbar_get_nth_item
-	(EGG_TOOLBAR (toolbar), position));
+  item = GTK_WIDGET (gtk_toolbar_get_nth_item
+	(GTK_TOOLBAR (toolbar), position));
+  g_return_if_fail (item != NULL);
   gtk_container_remove (GTK_CONTAINER (toolbar), item);
 
   if (egg_toolbars_model_n_items (model, toolbar_position) == 0)
-  {
-    gtk_widget_set_size_request (toolbar, -1, MIN_TOOLBAR_HEIGHT);
-    egg_toolbars_model_remove_toolbar (model, toolbar_position);
-  }
+    {
+      gtk_widget_set_size_request (toolbar, -1, MIN_TOOLBAR_HEIGHT);
+      egg_toolbars_model_remove_toolbar (model, toolbar_position);
+    }
 }
 
 static void
-egg_editable_toolbar_set_model (EggEditableToolbar *t,
-				EggToolbarsModel   *model)
+toolbars_clean (EggEditableToolbar *t)
 {
-  g_return_if_fail (IS_EGG_TOOLBARS_MODEL (model));
-  g_return_if_fail (IS_EGG_EDITABLE_TOOLBAR (t));
+  GList *children, *l;
 
-  t->priv->model = model;
+  unset_fixed_style (t);
+  unparent_fixed (t);
 
-  g_signal_connect_object (model, "item_added",
-			   G_CALLBACK (item_added_cb), t, 0);
-  g_signal_connect_object (model, "item_removed",
-			   G_CALLBACK (item_removed_cb), t, 0);
-  g_signal_connect_object (model, "toolbar_added",
-			   G_CALLBACK (toolbar_added_cb), t, 0);
-  g_signal_connect_object (model, "toolbar_removed",
-			   G_CALLBACK (toolbar_removed_cb), t, 0);
-  g_signal_connect_object (model, "toolbar_changed",
-			   G_CALLBACK (toolbar_changed_cb), t, 0);
+  children = gtk_container_get_children (GTK_CONTAINER (t));
+
+  for (l = children; l != NULL; l = l->next)
+    {
+      gtk_widget_destroy (GTK_WIDGET (l->data));
+    }
+
+  g_list_free (children);
 }
 
 static void
@@ -492,19 +843,46 @@ egg_editable_toolbar_construct (EggEditableToolbar *t)
 
   for (i = 0; i < n_toolbars; i++)
     {
-      GtkWidget *toolbar;
+      GtkWidget *toolbar, *dock;
+      EggTbModelFlags flags;
 
-      toolbar = create_toolbar (t);
-      gtk_box_pack_start (GTK_BOX (t), toolbar, FALSE, FALSE, 0);
+      dock = create_dock (t);
+      gtk_box_pack_start (GTK_BOX (t), dock, TRUE, TRUE, 0);
+      toolbar = get_toolbar_nth (t, i);
+
+      flags = egg_toolbars_model_get_flags (model, i);
+      if (flags & EGG_TB_MODEL_ICONS_ONLY)
+        {
+          gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), GTK_TOOLBAR_ICONS);
+          if (i == 0)
+            {
+	      set_fixed_style (t, GTK_TOOLBAR_ICONS);
+            }
+        }
 
       n_items = egg_toolbars_model_n_items (model, i);
       for (l = 0; l < n_items; l++)
         {
           GtkWidget *item;
+          GtkAction *action;
 
-          item = create_item (t, model, i, l);
-	  egg_toolbar_insert (EGG_TOOLBAR (toolbar),
-			      EGG_TOOL_ITEM (item), l);
+          item = create_item (t, model, i, l, &action);
+          if (item)
+            {
+	      gtk_toolbar_insert (GTK_TOOLBAR (toolbar),
+			          GTK_TOOL_ITEM (item), l);
+              /* FIXME Hack to make tooltip work from gtk */
+              if (action)
+                {
+                  g_object_notify (G_OBJECT (action), "tooltip");
+                }
+            }
+          else
+            {
+              egg_toolbars_model_remove_item (model, i, l);
+              l--;
+              n_items--;
+            }
         }
 
       if (n_items == 0)
@@ -512,18 +890,72 @@ egg_editable_toolbar_construct (EggEditableToolbar *t)
             gtk_widget_set_size_request (toolbar, -1, MIN_TOOLBAR_HEIGHT);
         }
     }
+
+    update_fixed (t);
+}
+
+static void
+egg_editable_toolbar_set_model (EggEditableToolbar *t,
+				EggToolbarsModel   *model)
+{
+  g_return_if_fail (EGG_IS_TOOLBARS_MODEL (model));
+  g_return_if_fail (EGG_IS_EDITABLE_TOOLBAR (t));
+
+  if (t->priv->model == model) return;
+
+  if (t->priv->model)
+    {
+       g_signal_handlers_disconnect_by_func
+         (t->priv->model, G_CALLBACK (item_added_cb), t);
+       g_signal_handlers_disconnect_by_func
+         (t->priv->model, G_CALLBACK (item_removed_cb), t);
+       g_signal_handlers_disconnect_by_func
+         (t->priv->model, G_CALLBACK (toolbar_added_cb), t);
+       g_signal_handlers_disconnect_by_func
+         (t->priv->model, G_CALLBACK (toolbar_removed_cb), t);
+       g_signal_handlers_disconnect_by_func
+         (t->priv->model, G_CALLBACK (toolbar_changed_cb), t);
+
+       g_object_unref (t->priv->model);
+    }
+
+  t->priv->model = g_object_ref (model);
+
+  toolbars_clean (t);
+  egg_editable_toolbar_construct (t);
+
+  g_signal_connect_object (model, "item_added",
+			   G_CALLBACK (item_added_cb), t, 0);
+  g_signal_connect_object (model, "item_removed",
+			   G_CALLBACK (item_removed_cb), t, 0);
+  g_signal_connect_object (model, "toolbar_added",
+			   G_CALLBACK (toolbar_added_cb), t, 0);
+  g_signal_connect_object (model, "toolbar_removed",
+			   G_CALLBACK (toolbar_removed_cb), t, 0);
+  g_signal_connect_object (model, "toolbar_changed",
+			   G_CALLBACK (toolbar_changed_cb), t, 0);
 }
 
 static void
 egg_editable_toolbar_set_merge (EggEditableToolbar *t,
-				EggMenuMerge       *merge)
+				GtkUIManager       *merge)
 {
-  g_return_if_fail (EGG_IS_MENU_MERGE (merge));
-  g_return_if_fail (IS_EGG_EDITABLE_TOOLBAR (t));
+  g_return_if_fail (GTK_IS_UI_MANAGER (merge));
+  g_return_if_fail (EGG_IS_EDITABLE_TOOLBAR (t));
 
-  t->priv->merge = merge;
+  if (t->priv->merge == merge) return;
 
-  egg_editable_toolbar_construct (t);
+  if (t->priv->merge)
+    {
+      g_object_unref (t->priv->merge);
+    }
+
+  t->priv->merge = g_object_ref (merge);
+
+  if (t->priv->model != NULL)
+    {
+      egg_editable_toolbar_construct (t);
+    }
 }
 
 static void
@@ -588,21 +1020,23 @@ egg_editable_toolbar_class_init (EggEditableToolbarClass *klass)
 				   g_param_spec_object ("MenuMerge",
 							"MenuMerge",
 							"Menu merge",
-							EGG_TYPE_MENU_MERGE,
+							GTK_TYPE_UI_MANAGER,
 							G_PARAM_READWRITE));
   g_object_class_install_property (object_class,
 				   PROP_TOOLBARS_MODEL,
 				   g_param_spec_object ("ToolbarsModel",
 							"ToolbarsModel",
 							"Toolbars Model",
-							EGG_TOOLBARS_MODEL_TYPE,
+							EGG_TYPE_TOOLBARS_MODEL,
 							G_PARAM_READWRITE));
+
+  g_type_class_add_private (object_class, sizeof (EggEditableToolbarPrivate));
 }
 
 static void
 egg_editable_toolbar_init (EggEditableToolbar *t)
 {
-  t->priv = g_new0 (EggEditableToolbarPrivate, 1);
+  t->priv = EGG_EDITABLE_TOOLBAR_GET_PRIVATE (t);
 
   t->priv->merge = NULL;
   t->priv->edit_mode = FALSE;
@@ -613,27 +1047,32 @@ egg_editable_toolbar_finalize (GObject *object)
 {
   EggEditableToolbar *t = EGG_EDITABLE_TOOLBAR (object);
 
-  g_return_if_fail (object != NULL);
-  g_return_if_fail (IS_EGG_EDITABLE_TOOLBAR (object));
+  if (t->priv->fixed_toolbar)
+    {
+      g_object_unref (t->priv->fixed_toolbar);
+    }
 
-  g_free (t->priv);
+  if (t->priv->merge)
+    {
+      g_object_unref (t->priv->merge);
+    }
+
+  if (t->priv->model)
+    {
+      g_object_unref (t->priv->model);
+    }
 
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 GtkWidget *
-egg_editable_toolbar_new (EggMenuMerge     *merge,
+egg_editable_toolbar_new (GtkUIManager     *merge,
 			  EggToolbarsModel *model)
 {
-  EggEditableToolbar *t;
-
-  t = EGG_EDITABLE_TOOLBAR (g_object_new (EGG_EDITABLE_TOOLBAR_TYPE,
-					  "ToolbarsModel", model,
-					  "MenuMerge", merge, NULL));
-
-  g_return_val_if_fail (t->priv != NULL, NULL);
-
-  return GTK_WIDGET (t);
+  return GTK_WIDGET (g_object_new (EGG_TYPE_EDITABLE_TOOLBAR,
+				   "ToolbarsModel", model,
+				   "MenuMerge", merge,
+				   NULL));
 }
 
 void
@@ -650,29 +1089,31 @@ egg_editable_toolbar_set_edit_mode (EggEditableToolbar *etoolbar,
       GtkWidget *toolbar;
 
       toolbar = get_toolbar_nth (etoolbar, i);
-      n_items = egg_toolbar_get_n_items (EGG_TOOLBAR (toolbar));
+      n_items = gtk_toolbar_get_n_items (GTK_TOOLBAR (toolbar));
       for (l = 0; l < n_items; l++)
         {
-	  EggToolItem *item;
+	  GtkToolItem *item;
 	  const char *action_name;
           gboolean is_separator;
-	  EggAction *action;
+	  GtkAction *action;
 
           action_name = egg_toolbars_model_item_nth
 		(etoolbar->priv->model, i, l,
 		 &is_separator);
 	  action = find_action (etoolbar, action_name);
 
-	  item = egg_toolbar_get_nth_item (EGG_TOOLBAR (toolbar), l);
-	  egg_tool_item_set_use_drag_window (item, mode);
+	  item = gtk_toolbar_get_nth_item (GTK_TOOLBAR (toolbar), l);
+	  gtk_tool_item_set_use_drag_window (item, mode);
 
           if (mode)
 	    {
+              set_drag_cursor (GTK_WIDGET (item));
 	      gtk_widget_set_sensitive (GTK_WIDGET (item), TRUE);
               set_item_drag_source (GTK_WIDGET (item), action, is_separator);
             }
 	  else
             {
+              unset_drag_cursor (GTK_WIDGET (item));
               gtk_drag_source_unset (GTK_WIDGET (item));
 
               if (!is_separator)
@@ -701,7 +1142,7 @@ egg_editable_toolbar_show (EggEditableToolbar *etoolbar,
       toolbar_name = egg_toolbars_model_toolbar_nth (model, i);
       if (strcmp (toolbar_name, name) == 0)
       {
-        gtk_widget_show (get_toolbar_nth (etoolbar, i));
+        gtk_widget_show (get_dock_nth (etoolbar, i));
       }
     }
 }
@@ -723,11 +1164,33 @@ egg_editable_toolbar_hide (EggEditableToolbar *etoolbar,
       toolbar_name = egg_toolbars_model_toolbar_nth (model, i);
       if (strcmp (toolbar_name, name) == 0)
       {
-        gtk_widget_hide (get_toolbar_nth (etoolbar, i));
+        gtk_widget_hide (get_dock_nth (etoolbar, i));
       }
     }
 }
 
+GtkToolbar *
+egg_editable_toolbar_set_fixed (EggEditableToolbar *etoolbar,
+				GtkWidget          *fixed)
+{
+  GtkWidget *fixed_item;
+
+  etoolbar->priv->fixed_toolbar = gtk_toolbar_new ();
+  gtk_toolbar_set_show_arrow (GTK_TOOLBAR (etoolbar->priv->fixed_toolbar), FALSE);
+  g_object_ref (etoolbar->priv->fixed_toolbar);
+  gtk_object_sink (GTK_OBJECT (etoolbar->priv->fixed_toolbar));
+
+  fixed_item = GTK_WIDGET (gtk_tool_item_new ());
+  gtk_toolbar_insert (GTK_TOOLBAR (etoolbar->priv->fixed_toolbar),
+                      GTK_TOOL_ITEM (fixed_item), 0);
+
+  gtk_container_add (GTK_CONTAINER (fixed_item), fixed);
+
+  update_fixed (etoolbar);
+
+  return GTK_TOOLBAR (etoolbar->priv->fixed_toolbar);
+}
+
 void
 egg_editable_toolbar_set_drag_dest (EggEditableToolbar   *etoolbar,
 				    const GtkTargetEntry *targets,
@@ -750,7 +1213,7 @@ egg_editable_toolbar_set_drag_dest (EggEditableToolbar   *etoolbar,
         GtkWidget *widget = get_toolbar_nth (etoolbar, i);
 
         gtk_drag_dest_unset (widget);
-        gtk_drag_dest_set (widget, GTK_DEST_DEFAULT_DROP,
+        gtk_drag_dest_set (widget, 0,
                            targets, n_targets,
                            GDK_ACTION_MOVE | GDK_ACTION_COPY);
       }
@@ -881,7 +1344,7 @@ style_set_cb (GtkWidget *widget,
 }
 
 GtkWidget *
-_egg_editable_toolbar_new_separator_image ()
+_egg_editable_toolbar_new_separator_image (void)
 {
   GtkWidget *image = gtk_image_new ();
   update_separator_image (GTK_IMAGE (image));
