@@ -15,11 +15,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-bookmarks-editor.c,v 1.118 2003/10/17 11:13:07 marco Exp $
+ * $Id: ephy-bookmarks-editor.c,v 1.127 2003/12/16 17:29:42 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include <gtk/gtktable.h>
@@ -34,7 +34,7 @@
 #include <gtk/gtkuimanager.h>
 #include <gtk/gtktoggleaction.h>
 #include <gdk/gdkkeysyms.h>
-#include <bonobo/bonobo-i18n.h>
+#include <glib/gi18n.h>
 #include <libgnomeui/gnome-stock-icons.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <string.h>
@@ -46,19 +46,20 @@
 #include "ephy-node-view.h"
 #include "ephy-window.h"
 #include "ephy-dnd.h"
-#include "ephy-prefs.h"
 #include "ephy-shell.h"
+#include "ephy-session.h"
 #include "ephy-file-helpers.h"
+#include "ephy-file-chooser.h"
 #include "popup-commands.h"
 #include "ephy-state.h"
 #include "window-commands.h"
-#include "ephy-debug.h"
 #include "ephy-gui.h"
 #include "ephy-stock-icons.h"
 #include "ephy-search-entry.h"
 #include "ephy-toolbars-model.h"
 #include "ephy-favicon-cache.h"
 #include "eel-gconf-extensions.h"
+#include "ephy-debug.h"
 
 static GtkTargetEntry topic_drag_dest_types [] =
 {
@@ -312,7 +313,11 @@ get_target_window (EphyBookmarksEditor *editor)
 	}
 	else
 	{
-		return GTK_WIDGET (ephy_shell_get_active_window (ephy_shell));
+		EphySession *session;
+
+		session = EPHY_SESSION (ephy_shell_get_session (ephy_shell));
+
+		return GTK_WIDGET (ephy_session_get_active_window (session));
 	}
 }
 
@@ -493,6 +498,27 @@ add_bookmarks_source (GtkListStore *store,
 	g_slist_free (l);
 }
 
+static void
+import_from_file_response_cb (GtkDialog *dialog, gint response,
+			      EphyBookmarksEditor *editor)
+{
+	char *filename;
+
+	if (response == EPHY_RESPONSE_OPEN)
+	{
+		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+
+		if (filename != NULL)
+		{
+			ephy_bookmarks_import (editor->priv->bookmarks, filename);			
+
+			g_free (filename);
+		}
+	}
+
+	gtk_widget_destroy (GTK_WIDGET (dialog));
+}
+
 static void
 import_dialog_response_cb (GtkDialog *dialog, gint response,
 			   EphyBookmarksEditor *editor)
@@ -516,15 +542,17 @@ import_dialog_response_cb (GtkDialog *dialog, gint response,
 
 		if (filename == NULL)
 		{
-			const char *title;
-			EphyEmbedSingle *single;
+			EphyFileChooser *dialog;
 
-			title = _("Import bookmarks from file");
-			single = ephy_embed_shell_get_embed_single
-				(EPHY_EMBED_SHELL (ephy_shell));
-			ephy_embed_single_show_file_picker
-				(single, GTK_WIDGET (editor), title, NULL,
-				 NULL, modeOpen, &filename, NULL, NULL);
+			dialog = ephy_file_chooser_new (_("Import bookmarks from file"),
+							GTK_WIDGET (editor),
+							GTK_FILE_CHOOSER_ACTION_OPEN,
+							NULL);
+			/* FIXME: set up some filters perhaps ? */
+			g_signal_connect (dialog, "response",
+					  G_CALLBACK (import_from_file_response_cb), editor);
+
+			gtk_widget_show (GTK_WIDGET (dialog));
 		}
 		else
 		{
@@ -576,9 +604,10 @@ cmd_bookmarks_import (GtkAction *action,
 	gtk_widget_show (label);
 
         store = GTK_LIST_STORE (gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING));
-	combo = gtk_combo_box_new (GTK_TREE_MODEL (store));
+	combo = gtk_combo_box_new_with_model (GTK_TREE_MODEL (store));
 	gtk_widget_show (combo); 
 	g_object_set_data (G_OBJECT (dialog), "combo_box", combo);
+	g_object_unref (store);
 
 	cell = gtk_cell_renderer_text_new ();
 	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), cell, TRUE);
@@ -887,16 +916,13 @@ ephy_bookmarks_editor_update_menu (EphyBookmarksEditor *editor)
 	if (GTK_IS_EDITABLE (focus_widget))
 	{
 		gboolean has_selection;
-		gboolean clipboard_contains_text;
 
 		has_selection = gtk_editable_get_selection_bounds
 			(GTK_EDITABLE (focus_widget), NULL, NULL);
-		clipboard_contains_text = gtk_clipboard_wait_is_text_available
-			(gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
 
 		cut = has_selection;
 		copy = has_selection;
-		paste = clipboard_contains_text;
+		paste = TRUE;
 		select_all = TRUE;
 	}
 	else
@@ -1160,8 +1186,6 @@ search_entry_search_cb (GtkWidget *entry, const char *search_text, EphyBookmarks
 
 	search_text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
 
-	GDK_THREADS_ENTER ();
-
 	ephy_node_filter_empty (editor->priv->bookmarks_filter);
 	ephy_node_filter_add_expression (editor->priv->bookmarks_filter,
 				         ephy_node_filter_expression_new (EPHY_NODE_FILTER_EXPRESSION_STRING_PROP_CONTAINS,
@@ -1174,8 +1198,6 @@ search_entry_search_cb (GtkWidget *entry, const char *search_text, EphyBookmarks
 								          search_text),
 				         0);
 	ephy_node_filter_done_changing (editor->priv->bookmarks_filter);
-
-	GDK_THREADS_LEAVE ();
 }
 
 static GtkWidget *
