@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks.c,v 1.67 2003/11/10 21:36:34 chpe Exp $
+ *  $Id: ephy-bookmarks.c,v 1.68 2003/12/16 17:29:43 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -335,7 +335,6 @@ compute_lower_fav (EphyNode *favorites, double *score)
 			result = child;
 		}
 	}
-	ephy_node_thaw (favorites);
 
 	if (result == NULL) *score = 0;
 
@@ -449,7 +448,6 @@ get_topics_list (EphyBookmarks *eb,
 			*no_topics = FALSE;
 		}
 	}
-	ephy_node_thaw (eb->priv->keywords);
 
 	return g_string_free (list, FALSE);
 }
@@ -497,7 +495,6 @@ topics_removed_cb (EphyNode *node,
 
 		g_free (list);
 	}
-	ephy_node_thaw (child);
 
 	g_signal_emit (G_OBJECT (eb), ephy_bookmarks_signals[TREE_CHANGED], 0);
 }
@@ -753,11 +750,9 @@ ephy_bookmarks_find_bookmark (EphyBookmarks *eb,
 
 		if (location != NULL && strcmp (url, location) == 0)
 		{
-			ephy_node_thaw (eb->priv->bookmarks);
 			return kid;
 		}
 	}
-	ephy_node_thaw (eb->priv->bookmarks);
 
 	return NULL;
 }
@@ -1054,7 +1049,6 @@ ephy_bookmarks_find_keyword (EphyBookmarks *eb,
 			 node = kid;
 		 }
 	}
-	ephy_node_thaw (eb->priv->keywords);
 
 	return node;
 }
