@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-encoding-menu.c,v 1.20 2003/11/05 22:56:14 chpe Exp $
+ *  $Id: ephy-encoding-menu.c,v 1.22 2003/12/19 20:16:51 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -186,11 +186,6 @@ update_encoding_menu_cb (GtkAction *dummy, EphyEncodingMenu *menu)
 	enc_node = ephy_encodings_get_node (p->encodings, encoding);
 	if (!EPHY_IS_NODE (enc_node))
 	{
-		g_warning ("Encountered unknown encoding '%s'"
-			   ". Please file a bug at http://bugzilla.gnome.o"
-			   "rg/enter_bug.cgi?product=epiphany\n",
-			   encoding);
-
 		goto build_menu;
 	}
 
@@ -200,7 +195,7 @@ update_encoding_menu_cb (GtkAction *dummy, EphyEncodingMenu *menu)
 	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), TRUE);
 
 	/* check if encoding was overridden */
-	is_automatic = (info->encoding_source < EMBED_ENCODING_PARENT_FORCED);
+	is_automatic = ephy_encoding_info_is_automatic (info);
 
 	action = gtk_action_group_get_action (p->action_group,
 					      "ViewEncodingAutomatic");
