@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history-window.c,v 1.63 2003/11/22 14:40:37 marco Exp $
+ *  $Id: ephy-history-window.c,v 1.64 2003/12/16 17:29:41 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -941,8 +941,6 @@ static void
 setup_filters (EphyHistoryWindow *editor,
 	       gboolean pages, gboolean sites)
 {
-	GDK_THREADS_ENTER ();
-
 	LOG ("Setup filters for pages %d and sites %d", pages, sites);
 
 	if (pages)
@@ -965,8 +963,6 @@ setup_filters (EphyHistoryWindow *editor,
 
 		ephy_node_filter_done_changing (editor->priv->sites_filter);
 	}
-
-	GDK_THREADS_LEAVE ();
 }
 
 static void
