@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-notebook.c,v 1.24 2003/10/06 13:53:56 chpe Exp $
+ *  $Id: ephy-notebook.c,v 1.26 2003/11/05 22:56:14 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -47,7 +47,7 @@
 #include <gtk/gtkimage.h>
 #include <gtk/gtkbutton.h>
 #include <gtk/gtkiconfactory.h>
-#include <bonobo/bonobo-i18n.h>
+#include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 
 #define AFTER_ALL_TABS -1
@@ -142,7 +142,7 @@ ephy_notebook_class_init (EphyNotebookClass *klass)
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (EphyNotebookClass, tab_added),
 			      NULL, NULL,
-			      ephy_marshal_VOID__OBJECT,
+			      g_cclosure_marshal_VOID__OBJECT,
 			      G_TYPE_NONE,
 			      1,
 			      GTK_TYPE_WIDGET);
@@ -152,7 +152,7 @@ ephy_notebook_class_init (EphyNotebookClass *klass)
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (EphyNotebookClass, tab_removed),
 			      NULL, NULL,
-			      ephy_marshal_VOID__OBJECT,
+			      g_cclosure_marshal_VOID__OBJECT,
 			      G_TYPE_NONE,
 			      1,
 			      GTK_TYPE_WIDGET);
@@ -162,7 +162,7 @@ ephy_notebook_class_init (EphyNotebookClass *klass)
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (EphyNotebookClass, tab_detached),
 			      NULL, NULL,
-			      ephy_marshal_VOID__OBJECT,
+			      g_cclosure_marshal_VOID__OBJECT,
 			      G_TYPE_NONE,
 			      1,
 			      GTK_TYPE_WIDGET);
@@ -172,7 +172,7 @@ ephy_notebook_class_init (EphyNotebookClass *klass)
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (EphyNotebookClass, tabs_reordered),
 			      NULL, NULL,
-			      ephy_marshal_VOID__VOID,
+			      g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE,
 			      0);
 
