@@ -1,5 +1,6 @@
 /*
- *  Copyright (C) 2000, 2001, 2002 Marco Pesenti Gritti
+ *  Copyright (C) 2000-2003 Marco Pesenti Gritti
+ *  Copyright (C) 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,28 +15,28 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-tab.h,v 1.13 2003/11/19 19:19:58 chpe Exp $
  */
 
 #ifndef EPHY_TAB_H
 #define EPHY_TAB_H
 
 #include "ephy-embed.h"
-#include "egg-action.h"
 
 #include <glib-object.h>
 #include <gtk/gtkwidget.h>
 
 G_BEGIN_DECLS
 
+#define EPHY_TYPE_TAB		(ephy_tab_get_type ())
+#define EPHY_TAB(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_TAB, EphyTab))
+#define EPHY_TAB_CLASS(k)	(G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_TAB, EphyTabClass))
+#define EPHY_IS_TAB(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_TAB))
+#define EPHY_IS_TAB_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_TAB))
+#define EPHY_TAB_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_TAB, EphyTabClass))
+
 typedef struct EphyTabClass EphyTabClass;
-
-#define EPHY_TAB_TYPE             (ephy_tab_get_type ())
-#define EPHY_TAB(obj)             (GTK_CHECK_CAST ((obj), EPHY_TAB_TYPE, EphyTab))
-#define EPHY_TAB_CLASS(klass)     (GTK_CHECK_CLASS_CAST ((klass), EPHY_TAB, EphyTabClass))
-#define IS_EPHY_TAB(obj)          (GTK_CHECK_TYPE ((obj), EPHY_TAB_TYPE))
-#define IS_EPHY_TAB_CLASS(klass)  (GTK_CHECK_CLASS_TYPE ((klass), EPHY_TAB))
-#define EPHY_TAB_GET_CLASS(obj)	  (G_TYPE_INSTANCE_GET_CLASS((obj), EPHY_TAB_TYPE, EphyTabClass))
-
 typedef struct EphyTab EphyTab;
 typedef struct EphyTabPrivate EphyTabPrivate;
 
@@ -43,7 +44,7 @@ typedef enum
 {
 	TAB_NAV_UP	= 1 << 0,
 	TAB_NAV_BACK	= 1 << 1,
-	TAB_NAV_FORWARD	= 1 << 2,
+	TAB_NAV_FORWARD	= 1 << 2
 } TabNavigationFlags;
 
 typedef enum
@@ -55,8 +56,10 @@ typedef enum
 
 struct EphyTab
 {
-        GObject parent;
-        EphyTabPrivate *priv;
+	GObject parent;
+
+	/*< private >*/
+	EphyTabPrivate *priv;
 };
 
 struct EphyTabClass
@@ -69,22 +72,22 @@ struct EphyTabClass
 
 GType			ephy_tab_get_type		(void);
 
-EphyTab	*		ephy_tab_new			(void);
+EphyTab	               *ephy_tab_new			(void);
 
-EggAction *		ephy_tab_get_action		(EphyTab *tab);
+GObject                *ephy_tab_get_action		(EphyTab *tab);
 
-EphyEmbed *		ephy_tab_get_embed		(EphyTab *tab);
+EphyEmbed              *ephy_tab_get_embed		(EphyTab *tab);
 
 void			ephy_tab_set_window		(EphyTab *tab,
 							 EphyWindow *window);
 
-EphyWindow *		ephy_tab_get_window		(EphyTab *tab);
+EphyWindow             *ephy_tab_get_window		(EphyTab *tab);
 
-const char *		ephy_tab_get_icon_address	(EphyTab *tab);
+const char             *ephy_tab_get_icon_address	(EphyTab *tab);
 
 gboolean		ephy_tab_get_load_status	(EphyTab *tab);
 
-const char *		ephy_tab_get_link_message	(EphyTab *tab);
+const char             *ephy_tab_get_link_message	(EphyTab *tab);
 
 
 int			ephy_tab_get_load_percent	(EphyTab *tab);
@@ -93,7 +96,7 @@ void			ephy_tab_set_location		(EphyTab *tab,
 							 const char *location,
 							 TabAddressExpire expire);
 
-const char *		ephy_tab_get_location		(EphyTab *tab);
+const char             *ephy_tab_get_location		(EphyTab *tab);
 
 TabNavigationFlags	ephy_tab_get_navigation_flags	(EphyTab *tab);
 
@@ -103,9 +106,9 @@ void			ephy_tab_get_size		(EphyTab *tab,
 							 int *width,
 							 int *height);
 
-const char *		ephy_tab_get_status_message	(EphyTab *tab);
+const char             *ephy_tab_get_status_message	(EphyTab *tab);
 
-const char *		ephy_tab_get_title		(EphyTab *tab);
+const char             *ephy_tab_get_title		(EphyTab *tab);
 
 void			ephy_tab_set_visibility		(EphyTab *tab,
 							 gboolean visible);
