@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.c,v 1.144 2003/12/08 15:21:31 chpe Exp $
+ *  $Id: ephy-window.c,v 1.149 2003/12/25 14:48:12 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -92,7 +92,7 @@ static GtkActionEntry ephy_menu_entries [] = {
 	{ "FileSaveAs", GTK_STOCK_SAVE_AS, N_("Save _As..."), "<shift><control>S",
 	  N_("Save the current page"),
 	  G_CALLBACK (window_cmd_file_save_as) },
-	{ "FilePrintSetup", NULL, N_("Print Set_up..."), NULL,
+	{ "FilePrintSetup", STOCK_PRINT_SETUP, N_("Print Set_up..."), NULL,
 	  N_("Setup the page settings for printing"),
 	  G_CALLBACK (window_cmd_file_print_setup) },
 	{ "FilePrintPreview", GTK_STOCK_PRINT_PREVIEW, N_("Print Pre_view"),"<control><shift>P",
@@ -318,6 +318,7 @@ struct EphyWindowPrivate
 	gboolean is_ppview;
 	gboolean has_size;
 	guint num_tabs;
+	guint tab_message_cid;
 
 	guint disable_js_chrome_notifier_id;
 	guint show_toolbars_notifier_id;
@@ -732,7 +733,7 @@ init_menu_updaters (EphyWindow *window)
 }
 
 static void
-setup_window (EphyWindow *window)
+setup_ui_manager (EphyWindow *window)
 {
 	GtkActionGroup *action_group;
 	GtkAction *action;
@@ -804,23 +805,6 @@ setup_window (EphyWindow *window)
 		g_warning ("Could not merge epiphany-ui.xml: %s", err->message);
 		g_clear_error (&err);
         }
-
-	gtk_ui_manager_ensure_update (GTK_UI_MANAGER (window->ui_merge));
-
-	init_menu_updaters (window);
-
-	window->priv->toolbar = toolbar_new (window);
-	gtk_widget_show (GTK_WIDGET (window->priv->toolbar));
-	gtk_box_pack_end (GTK_BOX (window->priv->menu_dock),
-			  GTK_WIDGET (window->priv->toolbar),
-			  FALSE, FALSE, 0);
-	g_signal_connect (window,
-			  "selection-received",
-			  G_CALLBACK (ephy_window_selection_received_cb),
-			  window);
-	g_signal_connect (window, "window-state-event",
-			  G_CALLBACK (ephy_window_state_event_cb),
-			  window);
 }
 
 static void
@@ -882,10 +866,19 @@ sync_tab_load_progress (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 static void
 sync_tab_message (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 {
+	GtkStatusbar *s = GTK_STATUSBAR (window->priv->statusbar);
+	const char *message;
+
 	if (window->priv->closing) return;
 
-	statusbar_set_message (EPHY_STATUSBAR (window->priv->statusbar),
-			       ephy_tab_get_status_message (tab));
+	message = ephy_tab_get_status_message (tab);
+
+	gtk_statusbar_pop (s, window->priv->tab_message_cid);
+
+	if (message)
+	{
+		gtk_statusbar_push (s, window->priv->tab_message_cid, message);
+	}
 }
 
 static void
@@ -1450,8 +1443,6 @@ setup_notebook (EphyWindow *window)
 	g_signal_connect (G_OBJECT (notebook), "tabs_reordered",
 			  G_CALLBACK (tabs_reordered_cb), window);
 
-	gtk_widget_show (GTK_WIDGET (notebook));
-
 	return notebook;
 }
 
@@ -1600,22 +1591,28 @@ ephy_window_init (EphyWindow *window)
 
 	ensure_default_icon ();
 
-	/* Setup the window and connect verbs */
-	setup_window (window);
+	g_object_ref (ephy_shell);
+
+	/* Setup the UI manager and connect verbs */
+	setup_ui_manager (window);
+
+	window->priv->toolbar = toolbar_new (window);
+	gtk_box_pack_end (GTK_BOX (window->priv->menu_dock),
+			  GTK_WIDGET (window->priv->toolbar),
+			  FALSE, FALSE, 0);
+
 
-	/* Setup window contents */
 	window->priv->notebook = setup_notebook (window);
 	gtk_box_pack_start (GTK_BOX (window->priv->main_vbox),
 			    GTK_WIDGET (window->priv->notebook),
 			    TRUE, TRUE, 0);
 
 	window->priv->statusbar = statusbar_new ();
-	gtk_widget_show (window->priv->statusbar);
 	gtk_box_pack_start (GTK_BOX (window->priv->main_vbox),
 			    GTK_WIDGET (window->priv->statusbar),
 			    FALSE, TRUE, 0);
-
-	g_object_ref (ephy_shell);
+	window->priv->tab_message_cid = gtk_statusbar_get_context_id
+		(GTK_STATUSBAR (window->priv->statusbar), "tab_message");
 
 	/* Initialize the menus */
 	window->priv->tabs_menu = ephy_tabs_menu_new (window);
@@ -1623,6 +1620,24 @@ ephy_window_init (EphyWindow *window)
 	window->priv->enc_menu = ephy_encoding_menu_new (window);
 	window->priv->bmk_menu = ephy_bookmarks_menu_new (window);
 
+	/* Once the window is sufficiently created let the extensions attach to it */
+	manager = EPHY_EXTENSION (ephy_shell_get_extensions_manager (ephy_shell));
+	ephy_extension_attach_window (manager, window);
+
+	/* show widgets */
+	gtk_widget_show (GTK_WIDGET (window->priv->toolbar));
+	gtk_widget_show (GTK_WIDGET (window->priv->notebook));
+	gtk_widget_show (window->priv->statusbar);
+
+	g_signal_connect (window,
+			  "selection-received",
+			  G_CALLBACK (ephy_window_selection_received_cb),
+			  window);
+	g_signal_connect (window, "window-state-event",
+			  G_CALLBACK (ephy_window_state_event_cb),
+			  window);
+
+	/* lockdown pref notifiers */
 	window->priv->disable_js_chrome_notifier_id = eel_gconf_notification_add
 		(CONF_LOCKDOWN_DISABLE_JAVASCRIPT_CHROME,
 		 (GConfClientNotifyFunc)chrome_notifier, window);
@@ -1643,9 +1658,10 @@ ephy_window_init (EphyWindow *window)
 		(CONF_LOCKDOWN_HIDE_MENUBAR,
 		 (GConfClientNotifyFunc)chrome_notifier, window);
 
-	/* Once the window is fully created let the extensions attach to it */
-	manager = EPHY_EXTENSION (ephy_shell_get_extensions_manager (ephy_shell));
-	ephy_extension_attach_window (manager, window);
+	/* ensure the UI is updated */
+	gtk_ui_manager_ensure_update (GTK_UI_MANAGER (window->ui_merge));
+
+	init_menu_updaters (window);
 }
 
 static void
@@ -1711,6 +1727,15 @@ ephy_window_set_print_preview (EphyWindow *window, gboolean enabled)
 	ephy_notebook_set_show_tabs (EPHY_NOTEBOOK (window->priv->notebook), !enabled);
 }
 
+
+GtkWidget *
+ephy_window_get_toolbar (EphyWindow *window)
+{
+	g_return_val_if_fail (EPHY_IS_WINDOW (window), NULL);
+
+	return GTK_WIDGET (window->priv->toolbar);
+}
+
 GtkWidget *
 ephy_window_get_notebook (EphyWindow *window)
 {
@@ -1719,6 +1744,14 @@ ephy_window_get_notebook (EphyWindow *window)
 	return GTK_WIDGET (window->priv->notebook);
 }
 
+GtkWidget *
+ephy_window_get_statusbar (EphyWindow *window)
+{
+	g_return_val_if_fail (EPHY_IS_WINDOW (window), NULL);
+
+	return GTK_WIDGET (window->priv->statusbar);
+}
+
 void
 ephy_window_add_tab (EphyWindow *window,
 		     EphyTab *tab,
@@ -2019,9 +2052,3 @@ ephy_window_set_zoom (EphyWindow *window,
 		ephy_embed_zoom_set (embed, zoom, TRUE);
 	}
 }
-
-Toolbar *
-ephy_window_get_toolbar (EphyWindow *window)
-{
-	return window->priv->toolbar;
-}
