@@ -16,11 +16,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: toolbar.c,v 1.72 2003/11/22 13:52:34 marco Exp $
+ *  $Id: toolbar.c,v 1.74 2003/12/27 10:32:42 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "toolbar.h"
@@ -116,7 +116,7 @@ toolbar_get_type (void)
                         (GInstanceInitFunc) toolbar_init
                 };
 
-                toolbar_type = g_type_register_static (EGG_EDITABLE_TOOLBAR_TYPE,
+                toolbar_type = g_type_register_static (EGG_TYPE_EDITABLE_TOOLBAR,
 						       "Toolbar",
 						       &our_info, 0);
         }
@@ -384,6 +384,7 @@ toolbar_setup_actions (Toolbar *t)
 	action = g_object_new (EPHY_TYPE_ZOOM_ACTION,
 			       "name", "Zoom",
 			       "label", _("Zoom"),
+			       "stock_id", GTK_STOCK_ZOOM_IN,
 			       "tooltip", _("Adjust the text size"),
 			       "zoom", 1.0,
 			       NULL);
@@ -452,38 +453,6 @@ init_bookmarks_toolbar (Toolbar *t)
 	}
 }
 
-static void
-update_toolbar_remove_flag (EphyToolbarsModel *model, gpointer data)
-{
-	int i, n_toolbars;
-	int not_removable = 0;
-
-	n_toolbars = egg_toolbars_model_n_toolbars
-		(EGG_TOOLBARS_MODEL (model));
-
-	/* If there is only one toolbar and the bookmarks bar */
-	if (n_toolbars <= 2)
-	{
-		not_removable = EGG_TB_MODEL_NOT_REMOVABLE;
-	}
-
-	for (i = 0; i < n_toolbars; i++)
-	{
-		const char *t_name;
-
-		t_name = egg_toolbars_model_toolbar_nth
-			(EGG_TOOLBARS_MODEL (model), i);
-		g_return_if_fail (t_name != NULL);
-
-		if (!(strcmp (t_name, "BookmarksBar") == 0))
-		{
-			egg_toolbars_model_set_flags
-				(EGG_TOOLBARS_MODEL (model),
-				 not_removable, i);
-		}
-	}
-}
-
 static void
 init_normal_mode (Toolbar *t)
 {
@@ -491,12 +460,7 @@ init_normal_mode (Toolbar *t)
 
 	model = EPHY_TOOLBARS_MODEL
 		(ephy_shell_get_toolbars_model (ephy_shell, FALSE));
-	g_signal_connect (EGG_TOOLBARS_MODEL (model), "toolbar_added",
-			  G_CALLBACK (update_toolbar_remove_flag),
-			  NULL);
-	g_signal_connect (EGG_TOOLBARS_MODEL (model), "toolbar_removed",
-			  G_CALLBACK (update_toolbar_remove_flag),
-			  NULL);
+
 	g_object_set (G_OBJECT (t),
 		      "ToolbarsModel", model,
 		      NULL);
