@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000, 2001, 2002 Marco Pesenti Gritti
+ *  Copyright (C) 2000-2003 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,19 +14,17 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: window-commands.h,v 1.15 2003/12/07 10:23:31 chpe Exp $
  */
 
 #include <gtk/gtkaction.h>
 
 #include "ephy-window.h"
-#include "ephy-embed-utils.h"
 
 void window_cmd_edit_find	(GtkAction *action,
 				 EphyWindow *window);
 
-void window_cmd_file_print	(GtkAction *action,
-				 EphyWindow *window);
-
 void window_cmd_view_stop	(GtkAction *action,
 				 EphyWindow *window);
 
@@ -75,12 +73,27 @@ void window_cmd_file_open	(GtkAction *action,
 void window_cmd_file_save_as    (GtkAction *action,
 				 EphyWindow *window);
 
+void window_cmd_file_print_setup (GtkAction *action,
+				  EphyWindow *window);
+
+void window_cmd_file_print_preview (GtkAction *action,
+				    EphyWindow *window);
+
+void window_cmd_file_print	(GtkAction *action,
+				 EphyWindow *window);
+
 void window_cmd_file_send_to	(GtkAction *action,
 				 EphyWindow *window);
 
 void window_cmd_file_close_window (GtkAction *action,
 				    EphyWindow *window);
 
+void window_cmd_edit_undo	(GtkAction *action,
+				 EphyWindow *window);
+
+void window_cmd_edit_redo	(GtkAction *action,
+				 EphyWindow *window);
+
 void window_cmd_edit_cut	(GtkAction *action,
 				 EphyWindow *window);
 
